==> ContentLicensing-1.0.2.tar.gz: ContentLicensing/tool/ContentLicensingTool.py <==
##################################################################################
#
#    Copyright (C) 2006 Utah State University, All rights reserved.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
##################################################################################

__author__  = '''Brent Lambert, David Ray, Jon Thomas'''
__docformat__ = 'plaintext'
__version__   = '$ Revision 0.0 $'[11:-2]

from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
from Products.ContentLicensing.config import *
from Products.CMFCore.utils import UniqueObject
from Products.CMFCore.ActionProviderBase import ActionProviderBase
from OFS.SimpleItem import SimpleItem
from OFS.PropertyManager import PropertyManager
from Globals import InitializeClass
from Products.CMFCore import permissions
from Products.PageTemplates.PageTemplateFile import PageTemplateFile
from Products.ContentLicensing.DublinCoreExtensions.interfaces import ILicensable, ILicense
from DateTime import DateTime
    

class ContentLicensingTool(UniqueObject, SimpleItem, PropertyManager, ActionProviderBase):
    """ Content Licensing Tool """
    
    security = ClassSecurityInfo()
    __implements__ = (SimpleItem.__implements__,
                      ActionProviderBase.__implements__)

    id = 'portal_contentlicensing'
    meta_type = 'ContentLicensingTool'
    title = 'Content Licensing Tool'
    plone_tool = True
    toolicon = 'tool.gif'

    _properties = PropertyManager._properties + (
        {'id':'DefaultSiteCopyright', 'type':'string', 'mode':'w'},
        {'id':'Jurisdiction', 'type':'string', 'mode':'w'},
        {'id':'DefaultSiteCopyrightHolder', 'type':'string', 'mode':'w'},
        {'id':'DefaultSiteLicense', 'type':'lines', 'mode':'w'},
        {'id':'SupportedLicenses', 'type':'lines', 'mode':'w'},
        {'id':'license_allRights', 'type':'lines', 'mode':'w'},
        {'id':'license_gnuFree', 'type':'lines', 'mode':'w'},
        {'id':'license_cc', 'type':'lines', 'mode':'w'},
    )

    SupportedLicenses   = ['license_allRights',
                           'license_gnuFree',
                           'license_cc']
    license_allRights   = ['All Rights Reserved',
                           'All Rights Reserved',
                           'None',
                           'None']
    license_gnuFree     = ['GNU Free Document License',
                           'GNU Free Document License',
                           'http://www.gnu.org/licenses/fdl.txt',
                           'None']
    license_cc          = ['Creative Commons License',
                           'Attribution 2.5',
                           'http://creativecommons.org/licenses/by-nc-sa/2.5/',
                           'http://creativecommons.org/images/public/somerights20.png']
    license_siteDefault = ['Site Default',
                           'None',
                           'None',
                           'None']
    license_other       = ['Other',
                           'None',
                           'None',
                           'None']
        
    DefaultSiteCopyright = 'Copyright %s' %DateTime().year()
    Jurisdiction = ''
    DefaultSiteCopyrightHolder = 'by the Contributing Authors'
    DefaultSiteLicense = license_allRights[:]

    cc_license_rdf = {'by':
                          {
                              'requires':['http://web.resource.org/cc/Attribution',
                                          'http://web.resource.org/cc/Notice'],
                              'permits':['http://web.resource.org/cc/Reproduction',
                                         'http://web.resource.org/cc/Distribution',
                                         'http://web.resource.org/cc/DerivativeWorks'],
                              'prohibits':[],
                          },
                      'by-nd':
                          {
                              'requires':['http://web.resource.org/cc/Attribution',
                                          'http://web.resource.org/cc/Notice'],
                              'permits':['http://web.resource.org/cc/Reproduction',
                                         'http://web.resource.org/cc/Distribution'],
                              'prohibits':[],
                          },
                      'by-nc-nd':
                          {
                              'requires':['http://web.resource.org/cc/Attribution',
                                          'http://web.resource.org/cc/Notice'],
                              'permits':['http://web.resource.org/cc/Reproduction',
                                         'http://web.resource.org/cc/Distribution'],
                              'prohibits':['http://web.resource.org/cc/CommercialUse'],
                          },
                      'by-nc':
                          {
                              'requires':['http://web.resource.org/cc/Attribution',
                                          'http://web.resource.org/cc/Notice'],
                              'permits':['http://web.resource.org/cc/Reproduction',
                                         'http://web.resource.org/cc/Distribution',
                                         'http://web.resource.org/cc/DerivativeWorks'],
                              'prohibits':['http://web.resource.org/cc/CommercialUse'],
                          },
                      'by-nc-sa':
                          {
                              'requires':['http://web.resource.org/cc/Attribution',
                                          'http://web.resource.org/cc/ShareAlike',
                                          'http://web.resource.org/cc/Notice'],
                              'permits':['http://web.resource.org/cc/Reproduction',
                                         'http://web.resource.org/cc/Distribution',
                                         'http://web.resource.org/cc/DerivativeWorks'],
                              'prohibits':['http://web.resource.org/cc/CommercialUse'],
                          },
                      'by-sa':
                          {
                              'requires':['http://web.resource.org/cc/Attribution',
                                          'http://web.resource.org/cc/ShareAlike',
                                          'http://web.resource.org/cc/Notice'],
                              'permits':['http://web.resource.org/cc/Reproduction',
                                         'http://web.resource.org/cc/Distribution',
                                         'http://web.resource.org/cc/DerivativeWorks'],
                              'prohibits':[],
                          },
                      'publicdomain':
                          {
                              'requires':[],
                              'permits':['http://web.resource.org/cc/Reproduction',
                                         'http://web.resource.org/cc/Distribution',
                                         'http://web.resource.org/cc/DerivativeWorks'],
                              'prohibits':[],
                          },
                      }

    manage_options = (({'label':'Overview', 'action':'manage_overview'},) +
                      PropertyManager.manage_options +
                      ActionProviderBase.manage_options)


    security.declareProtected(permissions.ManagePortal, 'manage_overview')
    manage_overview = PageTemplateFile('overview', WWW_DIR)

    
#    def __init__(self, id=None):
#        pass

    security.declareProtected(permissions.ModifyPortalContent, 'getLicenses')
    def getLicenses(self):
        """ return titles and ids for the supported licenses. """
        licenses = [self.license_siteDefault]
        for x in self.SupportedLicenses:
            licenses.append(getattr(self, x))
        licenses.append(self.license_other)
        return licenses

    security.declareProtected(permissions.ModifyPortalContent, 'getLicense')
    def getLicense(self, licenseId):
        """ return a license. """
        if 'Site Default' == licenseId:
            return self.license_siteDefault
        elif 'Other' == licenseId:
            return self.license_other
        else:
            for x in self.SupportedLicenses:
                sl = self.getProperty(x)
                if sl and sl[0] == licenseId:
                    return sl
            return None

    security.declareProtected(permissions.ModifyPortalContent, 'getLicenseAndHolderFromObject')
    def getLicenseAndHolderFromObject(self, obj):
        """
        Get the copyright holder and license from an object.
         """
        if ILicensable.providedBy(obj):
            license = ILicense(obj)
            return (license.getRightsHolder(), license.getRightsLicense())
        else:
            return None

    security.declareProtected(permissions.ModifyPortalContent, 'setLicense')
    def setLicense(self, obj, license):
        """ Set a license using the Dublin Core Annotations interface. """
        if hasattr(obj.REQUEST, 'copyright_holder'):
            license.setRightsHolder(obj.REQUEST['copyright_holder'])
        if hasattr(obj.REQUEST, 'license'):
            newLicense = obj.REQUEST['license']
            if 'Creative Commons License' == newLicense:
                license.setRightsLicense(['Creative Commons License',
                                          obj.REQUEST['license_cc_name'],
                                          obj.REQUEST['license_cc_url'],
                                          obj.REQUEST['license_cc_button']])
            elif 'Other' == newLicense:
                license.setRightsLicense(['Other',
                                          obj.REQUEST['license_other_name'],
                                          obj.REQUEST['license_other_url'],
                                          'None'])
            elif 'Site Default' == newLicense:
                license.setRightsLicense(self.license_siteDefault)
            else:
                license.setRightsLicense(self.getLicense(newLicense))
    
    security.declareProtected(permissions.View, 'getSiteDefaultLicenseByline')
    def getSiteDefaultLicenseByline(self):
        """ Get the site defaults for a copyright byline. """
        copyright = self.DefaultSiteCopyright
        holder = self.DefaultSiteCopyrightHolder
        license = self.DefaultSiteLicense
        license_name = license[1]
        if not license_name or 'None' == license_name:
            license_name = ''
        if 'Creative Commons License' == license[0]:
            license_name = license[0]
        license_url = license[2]
        if not license_url or 'None' == license_url:
            license_url = ''
        license_button = license[3]
        if not license_button or 'None' == license_button:
            license_button = ''
        return copyright, holder, license_name, license_url, license_button

    security.declareProtected(permissions.View, 'isLicensable')
    def isLicensable(self, obj):
        """ Is an object Licensable? """
        return ILicensable.providedBy(obj)

    security.declareProtected(permissions.View, 'setRightsLicense')
    def setRightsLicense(self, obj, newLicense):
        """ Set the Dublin Core Extension field. """
        if self.isLicensable(obj):
            license =  ILicense(obj)
            license.setRightsLicense(newLicense)

    security.declareProtected(permissions.View, 'setRightsHolder')
    def setRightsHolder(self, obj, holder):
        """ Set the Dublin Core Extension RightsHolder field. """
        if self.isLicensable(obj):
            license = ILicense(obj)
            license.setRightsHolder(holder)

InitializeClass(ContentLicensingTool)

==> ContentLicensing-1.0.3.tar.gz: ContentLicensing/tool/ContentLicensingTool.py <==
##################################################################################
#
#    Copyright (C) 2006 Utah State University, All rights reserved.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
##################################################################################

__author__  = '''Brent Lambert, David Ray, Jon Thomas'''
__docformat__ = 'plaintext'
__version__   = '$ Revision 0.0 $'[11:-2]

from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
from Products.ContentLicensing.config import *
from Products.CMFCore.utils import UniqueObject
from Products.CMFCore.ActionProviderBase import ActionProviderBase
from OFS.SimpleItem import SimpleItem
from OFS.PropertyManager import PropertyManager
from Globals import InitializeClass
from Products.CMFCore import permissions
from Products.PageTemplates.PageTemplateFile import PageTemplateFile
from Products.ContentLicensing.DublinCoreExtensions.interfaces import ILicensable, ILicense
from DateTime import DateTime
    

class ContentLicensingTool(UniqueObject, SimpleItem, PropertyManager, ActionProviderBase):
    """ Content Licensing Tool """
    
    security = ClassSecurityInfo()
    __implements__ = (SimpleItem.__implements__,
                      ActionProviderBase.__implements__)

    id = 'portal_contentlicensing'
    meta_type = 'ContentLicensingTool'
    title = 'Content Licensing Tool'
    plone_tool = True
    toolicon = 'tool.gif'

    _properties = PropertyManager._properties + (
        {'id':'DefaultSiteCopyright', 'type':'string', 'mode':'w'},
        {'id':'Jurisdiction', 'type':'selection', 'mode':'w', 'select_variable' : 'allowedJurisdictions'},
        {'id':'DefaultSiteCopyrightHolder', 'type':'string', 'mode':'w'},
        {'id':'DefaultSiteLicense', 'type':'lines', 'mode':'w'},
        {'id':'SupportedLicenses', 'type':'lines', 'mode':'w'},
         {'id':'AvailableLicenses', 'type':'lines', 'mode':'w'},
        {'id':'license_allRights', 'type':'lines', 'mode':'w'},
        {'id':'license_gnuFree', 'type':'lines', 'mode':'w'},
        {'id':'license_cc', 'type':'lines', 'mode':'w'},
    )

    SupportedLicenses   = ['license_allRights',
                           'license_gnuFree',
                           'license_cc']
    AvailableLicenses = ['license_allRights',
                             'license_gnuFree',
                             'license_cc']
                             
    license_allRights   = ['All Rights Reserved',
                           'All Rights Reserved',
                           'None',
                           'None']
    license_gnuFree     = ['GNU Free Document License',
                           'GNU Free Document License',
                           'http://www.gnu.org/licenses/fdl.txt',
                           'None']
    license_cc          = ['Creative Commons License',
                           'Attribution-Noncommercial-Share Alike 2.5',
                           'http://creativecommons.org/licenses/by-nc-sa/2.5/',
                           'http://i.creativecommons.org/l/by-nc-sa/2.5/88x31.png']
    license_siteDefault = ['Site Default',
                           'None',
                           'None',
                           'None']
    license_other       = ['Other',
                           'None',
                           'None',
                           'None']
        
    DefaultSiteCopyright = 'Copyright %s' %DateTime().year()
    DefaultSiteCopyrightHolder = 'by the Contributing Authors'
    DefaultSiteLicense = license_allRights[:]

    allowedJurisdictions = (('generic', 'Generic'), ('ar', 'Argentina'), ('au', 'Australia'), ('at', 'Austria' ), 
                            ('be', 'Belgium' ), ('br', 'Brazil'), ('bg', 'Bulgaria' ),
                            ('ca', 'Canada'), ('cl', 'Chile'), ('cn', 'Mainland China'), ('co', 'Colombia'), 
                            ('dk', 'Denmark'), ('hr', 'Croatia'), ('fi', 'Finland'), ('fr', 'France'), 
                            ('de', 'Germany'), ('hu', 'Hungary'), ('il', 'Israel'), ('it', 'Italy'), ('jp', 'Japan'), 
                            ('kr', 'South Korea'), ('my', 'Malaysia'), ('mt', 'Malta'), 
                            ('mx', 'Mexico'), ('nl', 'Netherlands'), ('pe', 'Peru'), ('pl', 'Poland'), ('pt', 'Portugal'), 
                            ('si', 'Slovenia'), ('za', 'South Africa'), ('es', 'Spain'), 
                            ('se', 'Sweden'), ('tw', 'Taiwan'), ('uk', 'UK:England and Wales'), ('scotland', 'UK:Scotland'))

    Jurisdiction = allowedJurisdictions[0][1]

    cc_license_rdf = {'by':
                          {
                              'requires':['http://web.resource.org/cc/Attribution',
                                          'http://web.resource.org/cc/Notice'],
                              'permits':['http://web.resource.org/cc/Reproduction',
                                         'http://web.resource.org/cc/Distribution',
                                         'http://web.resource.org/cc/DerivativeWorks'],
                              'prohibits':[],
                          },
                      'by-nd':
                          {
                              'requires':['http://web.resource.org/cc/Attribution',
                                          'http://web.resource.org/cc/Notice'],
                              'permits':['http://web.resource.org/cc/Reproduction',
                                         'http://web.resource.org/cc/Distribution'],
                              'prohibits':[],
                          },
                      'by-nc-nd':
                          {
                              'requires':['http://web.resource.org/cc/Attribution',
                                          'http://web.resource.org/cc/Notice'],
                              'permits':['http://web.resource.org/cc/Reproduction',
                                         'http://web.resource.org/cc/Distribution'],
                              'prohibits':['http://web.resource.org/cc/CommercialUse'],
                          },
                      'by-nc':
                          {
                              'requires':['http://web.resource.org/cc/Attribution',
                                          'http://web.resource.org/cc/Notice'],
                              'permits':['http://web.resource.org/cc/Reproduction',
                                         'http://web.resource.org/cc/Distribution',
                                         'http://web.resource.org/cc/DerivativeWorks'],
                              'prohibits':['http://web.resource.org/cc/CommercialUse'],
                          },
                      'by-nc-sa':
                          {
                              'requires':['http://web.resource.org/cc/Attribution',
                                          'http://web.resource.org/cc/ShareAlike',
                                          'http://web.resource.org/cc/Notice'],
                              'permits':['http://web.resource.org/cc/Reproduction',
                                         'http://web.resource.org/cc/Distribution',
                                         'http://web.resource.org/cc/DerivativeWorks'],
                              'prohibits':['http://web.resource.org/cc/CommercialUse'],
                          },
                      'by-sa':
                          {
                              'requires':['http://web.resource.org/cc/Attribution',
                                          'http://web.resource.org/cc/ShareAlike',
                                          'http://web.resource.org/cc/Notice'],
                              'permits':['http://web.resource.org/cc/Reproduction',
                                         'http://web.resource.org/cc/Distribution',
                                         'http://web.resource.org/cc/DerivativeWorks'],
                              'prohibits':[],
                          },
                      'publicdomain':
                          {
                              'requires':[],
                              'permits':['http://web.resource.org/cc/Reproduction',
                                         'http://web.resource.org/cc/Distribution',
                                         'http://web.resource.org/cc/DerivativeWorks'],
                              'prohibits':[],
                          },
                      }

    manage_options = (({'label':'Overview', 'action':'manage_overview'},) +
                      PropertyManager.manage_options +
                      ActionProviderBase.manage_options)


    security.declareProtected(permissions.ManagePortal, 'manage_overview')
    manage_overview = PageTemplateFile('overview', WWW_DIR)

    
#    def __init__(self, id=None):
#        pass

    security.declareProtected(permissions.ModifyPortalContent, 'getLicenses')
    def getLicenses(self):
        """ return titles and ids for the supported licenses. """
        licenses = [self.license_siteDefault]
        for x in self.AvailableLicenses:
            licenses.append(getattr(self, x))
        licenses.append(self.license_other)
        return licenses

    
    security.declareProtected(permissions.ModifyPortalContent, 'getSupportedLicenses')
    def getSupportedLicenses(self):
        """ return titles and ids for the supported licenses in the configlet """
        licenses = []
        for x in self.SupportedLicenses:
            licenses.append([x, getattr(self, x)[0], getattr(self, x)[1]])
        return licenses

    
    security.declareProtected(permissions.ModifyPortalContent, 'getAvailableLicenses')
    def getAvailableLicenses(self):
        """ return titles and ids for the supported licenses. """
        licenses = []
        for x in self.AvailableLicenses:
            licenses.append(x)
        return licenses


    security.declareProtected(permissions.ModifyPortalContent, 'getLicense')
    def getLicense(self, licenseId):
        """ return a license. """
        if 'Site Default' == licenseId:
            return self.license_siteDefault
        elif 'Other' == licenseId:
            return self.license_other
        else:
            for x in self.SupportedLicenses:
                sl = self.getProperty(x)
                if sl and sl[0] == licenseId:
                    return sl
            return None

    security.declareProtected(permissions.ModifyPortalContent, 'getLicenseAndHolderFromObject')
    def getLicenseAndHolderFromObject(self, obj):
        """
        Get the copyright holder and license from an object.
         """
        if ILicensable.providedBy(obj):
            license = ILicense(obj)
            return (license.getRightsHolder(), license.getRightsLicense())
        else:
            return None

    security.declareProtected(permissions.ModifyPortalContent, 'setLicense')
    def setLicense(self, obj, license):
        """ Set a license using the Dublin Core Annotations interface. """
        if hasattr(obj.REQUEST, 'copyright_holder'):
            license.setRightsHolder(obj.REQUEST['copyright_holder'])
        if hasattr(obj.REQUEST, 'license'):
            newLicense = obj.REQUEST['license']
            if 'Creative Commons License' == newLicense:
                license.setRightsLicense(['Creative Commons License',
                                          obj.REQUEST['license_cc_name'],
                                          obj.REQUEST['license_cc_url'],
                                          obj.REQUEST['license_cc_button']])
            elif 'Other' == newLicense:
                license.setRightsLicense(['Other',
                                          obj.REQUEST['license_other_name'],
                                          obj.REQUEST['license_other_url'],
                                          'None'])
            elif 'Site Default' == newLicense:
                license.setRightsLicense(self.license_siteDefault)
            else:
                license.setRightsLicense(self.getLicense(newLicense))
    
    security.declareProtected(permissions.View, 'getSiteDefaultLicenseByline')
    def getSiteDefaultLicenseByline(self):
        """ Get the site defaults for a copyright byline. """
        copyright = self.DefaultSiteCopyright
        holder = self.DefaultSiteCopyrightHolder
        license = self.DefaultSiteLicense
        license_name = license[1]
        if not license_name or 'None' == license_name:
            license_name = ''
        if 'Creative Commons License' == license[0]:
            license_name = license[0]
        license_url = license[2]
        if not license_url or 'None' == license_url:
            license_url = ''
        license_button = license[3]
        if not license_button or 'None' == license_button:
            license_button = ''
        return copyright, holder, license_name, license_url, license_button

    security.declareProtected(permissions.View, 'isLicensable')
    def isLicensable(self, obj):
        """ Is an object Licensable? """
        return ILicensable.providedBy(obj)

    security.declareProtected(permissions.View, 'setRightsLicense')
    def setRightsLicense(self, obj, newLicense):
        """ Set the Dublin Core Extension field. """
        if self.isLicensable(obj):
            license =  ILicense(obj)
            license.setRightsLicense(newLicense)

    security.declareProtected(permissions.View, 'setRightsHolder')
    def setRightsHolder(self, obj, holder):
        """ Set the Dublin Core Extension RightsHolder field. """
        if self.isLicensable(obj):
            license = ILicense(obj)
            license.setRightsHolder(holder)

    security.declareProtected(permissions.ModifyPortalContent, 'listSupportedJurisdictions')
    def listSupportedJurisdictions(self):
        """Returns a list of supported jurisdiction codes"""
        r = []
        for j in self.allowedJurisdictions:
            r.append([j[0], j[1]])
        return r

    security.declareProtected(permissions.ModifyPortalContent, 'getJurisdictionCode')
    def getJurisdictionCode(self):
        """Returns the current Jurisdiction Code"""
        juris = self.Jurisdiction
        allowed = dict([(y, x) for x, y in self.allowedJurisdictions])
        juris_code = allowed[juris]
        if juris_code == 'generic':
            juris_code = ''
        return juris_code

InitializeClass(ContentLicensingTool)
